"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const util_1 = require("util");
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const test_commons_1 = require("../../../test-commons");
const rimraf = util_1.promisify(require('rimraf'));
const DEST_DIR = path_1.default.join(process.cwd(), 'src', 'test', 'generated', 'generators', 'react-typescript', 'entity-details');
const getOwnerQuery = `
query Get_Owner($id: BigInteger) {
  owner(id: $id) {
    id
    firstName
    lastName
    city
    address
    email
    telephone
  }
}
`;
const ownerUpsertMutation = `
mutation Update_Owner($input: OwnerInputDTOInput) {
  update_Owner(input: $input) {
    id
  }
}
`;
describe('codegen entity-details test', () => {
    before(async () => {
        await rimraf(`${DEST_DIR}/{*,.*}`);
        !fs_1.default.existsSync(DEST_DIR) && fs_1.default.mkdirSync(DEST_DIR, { recursive: true });
        // avoid exception on read i18n messages in mvp.ts, create file first TODO - fix in mpv.ts 'addScreenI18nKeyEn'
        fs_1.default.mkdirSync(path_1.default.join(DEST_DIR, 'core', 'i18n'), { recursive: true });
        fs_1.default.writeFileSync(path_1.default.join(DEST_DIR, 'core', 'i18n', 'en.json'), '{}');
    });
    it('should generate entity details screen', async () => {
        const detailsAnswers = {
            query: getOwnerQuery,
            componentName: 'OwnerDetails',
            shouldAddToMenu: false
        };
        const componentPath = path_1.default.join(DEST_DIR, 'OwnerDetails.tsx');
        chai_1.expect(!fs_1.default.existsSync(componentPath));
        await commons_1.generate(path_1.default.join(commons_1.GENERATORS_DIR, 'react-typescript', 'entity-details'), commons_1.opts(DEST_DIR, detailsAnswers, commons_1.SCHEMA_PATH));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function OwnerDetails');
        chai_1.expect(componentFile).to.contain('query Get_Owner($id: BigInteger) {');
    });
    it('should generate entity editor screen - Owner', async () => {
        const editorAnswers = {
            query: getOwnerQuery,
            route: 'owner-editor',
            refetchQueryName: 'Get_Owner',
            mutation: ownerUpsertMutation,
            componentName: 'OwnerEditor',
            shouldAddToMenu: false
        };
        const componentPath = path_1.default.join(DEST_DIR, 'OwnerEditor.tsx');
        chai_1.expect(!fs_1.default.existsSync(componentPath));
        await commons_1.generate(path_1.default.join(commons_1.GENERATORS_DIR, 'react-typescript', 'entity-details'), commons_1.opts(DEST_DIR, editorAnswers, commons_1.SCHEMA_PATH));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function OwnerEditor');
        chai_1.expect(componentFile).to.contain('query Get_Owner($id: BigInteger) {');
        chai_1.expect(componentFile).to.contain('mutation Update_Owner($input: OwnerInputDTOInput) {');
    });
    it('should generate entity editor screen - TestDTO ', async () => {
        const updateMutation = `
      mutation Update_TestDto($input: TestInputDTOInput) {
        update_Test(input: $input) {
          id
        }
      }`;
        const findQuery = `
      query Get_TestDto($id: BigInteger) {
        test(id: $id) {
          id
          electric
          name
        }
      }`;
        const answers = {
            query: findQuery,
            route: 'test-dto-editor',
            refetchQueryName: 'Get_TestDto',
            mutation: updateMutation,
            componentName: 'TestDtoEditor',
            shouldAddToMenu: false
        };
        const componentPath = path_1.default.join(DEST_DIR, 'TestDtoEditor.tsx');
        chai_1.expect(!fs_1.default.existsSync(componentPath));
        await commons_1.generate(path_1.default.join(commons_1.GENERATORS_DIR, 'react-typescript', 'entity-details'), commons_1.opts(DEST_DIR, answers, commons_1.SCHEMA_PATH));
        const expectBoolFormItem = `
        <Form.Item
          name="bool"
          label="Bool"
          style={{ marginBottom: "12px" }}
          valuePropName="checked"
        >
          <Checkbox />
        </Form.Item>`;
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function TestDtoEditor');
        // compare form item ignore spaces
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectBoolFormItem);
    });
});
//# sourceMappingURL=entity-details.test.js.map