"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const util_1 = require("util");
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const test_commons_1 = require("../../../test-commons");
const queries_1 = require("../common/queries");
const rimraf = util_1.promisify(require('rimraf'));
const DEST_DIR = path_1.default.join(process.cwd(), 'src', 'test', 'generated', 'generators', 'react-typescript', 'entity-list');
const displayNameFunctionFile = path_1.default.join(DEST_DIR, 'display-name', 'getOwnerDTODisplayName.ts');
describe('codegen standalone table', () => {
    before(async () => {
        await rimraf(`${DEST_DIR}/{*,.*}`);
        !fs_1.default.existsSync(DEST_DIR) && fs_1.default.mkdirSync(DEST_DIR, { recursive: true });
        // avoid exception on read i18n messages in mvp.ts, create file first TODO - fix in mpv.ts 'addScreenI18nKeyEn'
        fs_1.default.mkdirSync(path_1.default.join(DEST_DIR, 'core', 'i18n'), { recursive: true });
        fs_1.default.writeFileSync(path_1.default.join(DEST_DIR, 'core', 'i18n', 'en.json'), '{}');
    });
    it('should generate standalone table screen - Owner', async () => {
        const answers = {
            componentName: 'StandaloneOwnerTable',
            route: 'standalone-owner-table',
            shouldAddToMenu: false,
            query: queries_1.ownerListQuery,
            mutation: queries_1.ownerDeleteMutation,
            type: 'table',
            mode: 'edit'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'StandaloneOwnerTable.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(!fs_1.default.existsSync(componentPath));
        chai_1.expect(!fs_1.default.existsSync(displayNameFunctionFile));
        await commons_1.generate(path_1.default.join(commons_1.GENERATORS_DIR, 'react-typescript', 'entity-list'), commons_1.opts(DEST_DIR, answers, commons_1.SCHEMA_PATH));
        const expectTag = `
    <Space direction="vertical" style={{ width: "100%" }}>
      <Table
        dataSource={items.filter(item => item != null) as object[]}
        columns={columns}
        rowClassName={record =>
          (record as ItemType)?.id === selectedRowId ? "table-row-selected" : ""
        }
        onRow={data => {
          return { onClick: () => setSelectedRowId((data as ItemType)?.id) };
        }}
      />
    </Space>`;
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function StandaloneOwnerTable() ');
        chai_1.expect(componentFile).to.contain('query Get_Owner_List {');
        chai_1.expect(componentFile).to.contain('mutation Delete_Owner($id: BigInteger!) {');
        // columns
        chai_1.expect(componentFile).to.contain('title: "Address",');
        chai_1.expect(componentFile).to.contain('title: "City",');
        chai_1.expect(componentFile).to.contain('title: "Email",');
        chai_1.expect(componentFile).to.contain('title: "First Name",');
        chai_1.expect(componentFile).to.contain('title: "Last Name",');
        chai_1.expect(componentFile).to.contain('title: "Telephone",');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectTag);
        // check that displayName function is NOT written for 'table'
        chai_1.expect(!fs_1.default.existsSync(displayNameFunctionFile));
    });
    it('should generate standalone table screen - Pet', async () => {
        const answers = {
            componentName: 'StandalonePetTable',
            route: 'standalone-pet-table',
            shouldAddToMenu: false,
            query: queries_1.petListQuery,
            mutation: queries_1.petDeleteMutation,
            mode: 'edit',
            type: 'table'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'StandalonePetTable.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(!fs_1.default.existsSync(componentPath));
        chai_1.expect(!fs_1.default.existsSync(displayNameFunctionFile));
        await commons_1.generate(path_1.default.join(commons_1.GENERATORS_DIR, 'react-typescript', 'entity-list'), commons_1.opts(DEST_DIR, answers, commons_1.SCHEMA_PATH));
        const expectTag = `
    <Space direction="vertical" style={{ width: "100%" }}>
      <Table
        dataSource={items.filter(item => item != null) as object[]}
        columns={columns}
        rowClassName={record =>
          (record as ItemType)?.id === selectedRowId ? "table-row-selected" : ""
        }
        onRow={data => {
          return { onClick: () => setSelectedRowId((data as ItemType)?.id) };
        }}
      />
    </Space>`;
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function StandalonePetTable() ');
        chai_1.expect(componentFile).to.contain('query Get_Pet_List {');
        chai_1.expect(componentFile).to.contain('mutation Delete_Pet($id: BigInteger!) {');
        // columns
        chai_1.expect(componentFile).to.contain('title: "Birth Date",');
        chai_1.expect(componentFile).to.contain('title: "Identification Number",');
        chai_1.expect(componentFile).to.contain('title: "Owner",');
        chai_1.expect(componentFile).to.contain('title: "Type",');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectTag);
        // check that displayName function is written for 'table'
        chai_1.expect(fs_1.default.existsSync(displayNameFunctionFile));
    });
});
//# sourceMappingURL=standalone-table.test.js.map